# -*- coding: utf-8 -*-

#
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_SimulatorTab(object):
    def setupUi(self, SimulatorTab):
        SimulatorTab.setObjectName("SimulatorTab")
        SimulatorTab.resize(842, 689)
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(SimulatorTab)
        self.verticalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_8.setSpacing(0)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.scrollArea = QtWidgets.QScrollArea(SimulatorTab)
        self.scrollArea.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 842, 689))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.splitterLeftRight = QtWidgets.QSplitter(self.scrollAreaWidgetContents)
        self.splitterLeftRight.setStyleSheet(
            "QSplitter::handle:horizontal {\n"
            "margin: 4px 0px;\n"
            "    background-color: qlineargradient(x1:0, y1:0, x2:0, y2:1, \n"
            "stop:0 rgba(255, 255, 255, 0), \n"
            "stop:0.5 rgba(100, 100, 100, 100), \n"
            "stop:1 rgba(255, 255, 255, 0));\n"
            "image: url(:/icons/icons/splitter_handle_vertical.svg);\n"
            "}"
        )
        self.splitterLeftRight.setOrientation(QtCore.Qt.Horizontal)
        self.splitterLeftRight.setHandleWidth(6)
        self.splitterLeftRight.setObjectName("splitterLeftRight")
        self.layoutWidget = QtWidgets.QWidget(self.splitterLeftRight)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout_3.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.label = QtWidgets.QLabel(self.layoutWidget)
        self.label.setObjectName("label")
        self.verticalLayout_3.addWidget(self.label)
        self.treeProtocols = GeneratorTreeView(self.layoutWidget)
        self.treeProtocols.setObjectName("treeProtocols")
        self.verticalLayout_3.addWidget(self.treeProtocols)
        self.label_6 = QtWidgets.QLabel(self.layoutWidget)
        self.label_6.setObjectName("label_6")
        self.verticalLayout_3.addWidget(self.label_6)
        self.listViewSimulate = QtWidgets.QListView(self.layoutWidget)
        self.listViewSimulate.setAlternatingRowColors(True)
        self.listViewSimulate.setObjectName("listViewSimulate")
        self.verticalLayout_3.addWidget(self.listViewSimulate)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.label_4 = QtWidgets.QLabel(self.layoutWidget)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 0, 0, 1, 1)
        self.spinBoxNRepeat = QtWidgets.QSpinBox(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.spinBoxNRepeat.sizePolicy().hasHeightForWidth()
        )
        self.spinBoxNRepeat.setSizePolicy(sizePolicy)
        self.spinBoxNRepeat.setMaximum(9999999)
        self.spinBoxNRepeat.setObjectName("spinBoxNRepeat")
        self.gridLayout.addWidget(self.spinBoxNRepeat, 0, 1, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.layoutWidget)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 1, 0, 1, 1)
        self.spinBoxTimeout = QtWidgets.QSpinBox(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.spinBoxTimeout.sizePolicy().hasHeightForWidth()
        )
        self.spinBoxTimeout.setSizePolicy(sizePolicy)
        self.spinBoxTimeout.setMinimum(1)
        self.spinBoxTimeout.setMaximum(9999999)
        self.spinBoxTimeout.setObjectName("spinBoxTimeout")
        self.gridLayout.addWidget(self.spinBoxTimeout, 1, 1, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.layoutWidget)
        self.label_7.setObjectName("label_7")
        self.gridLayout.addWidget(self.label_7, 2, 0, 1, 1)
        self.comboBoxError = QtWidgets.QComboBox(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.comboBoxError.sizePolicy().hasHeightForWidth()
        )
        self.comboBoxError.setSizePolicy(sizePolicy)
        self.comboBoxError.setObjectName("comboBoxError")
        self.comboBoxError.addItem("")
        self.comboBoxError.addItem("")
        self.comboBoxError.addItem("")
        self.gridLayout.addWidget(self.comboBoxError, 2, 1, 1, 1)
        self.label_8 = QtWidgets.QLabel(self.layoutWidget)
        self.label_8.setObjectName("label_8")
        self.gridLayout.addWidget(self.label_8, 3, 0, 1, 1)
        self.spinBoxRetries = QtWidgets.QSpinBox(self.layoutWidget)
        self.spinBoxRetries.setMinimum(1)
        self.spinBoxRetries.setMaximum(9999999)
        self.spinBoxRetries.setProperty("value", 10)
        self.spinBoxRetries.setObjectName("spinBoxRetries")
        self.gridLayout.addWidget(self.spinBoxRetries, 3, 1, 1, 1)
        self.verticalLayout_3.addLayout(self.gridLayout)
        self.btnStartSim = QtWidgets.QPushButton(self.layoutWidget)
        icon = QtGui.QIcon.fromTheme("media-playback-start")
        self.btnStartSim.setIcon(icon)
        self.btnStartSim.setObjectName("btnStartSim")
        self.verticalLayout_3.addWidget(self.btnStartSim)
        self.splitter = QtWidgets.QSplitter(self.splitterLeftRight)
        self.splitter.setStyleSheet(
            "QSplitter::handle:vertical {\n"
            "margin: 4px 0px;\n"
            "    background-color: qlineargradient(x1:0, y1:0, x2:1, y2:0, \n"
            "stop:0 rgba(255, 255, 255, 0), \n"
            "stop:0.5 rgba(100, 100, 100, 100), \n"
            "stop:1 rgba(255, 255, 255, 0));\n"
            "image: url(:/icons/icons/splitter_handle_horizontal.svg);\n"
            "}"
        )
        self.splitter.setOrientation(QtCore.Qt.Vertical)
        self.splitter.setHandleWidth(6)
        self.splitter.setObjectName("splitter")
        self.layoutWidget_2 = QtWidgets.QWidget(self.splitter)
        self.layoutWidget_2.setObjectName("layoutWidget_2")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.layoutWidget_2)
        self.verticalLayout_2.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.tabWidget = QtWidgets.QTabWidget(self.layoutWidget_2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setStyleSheet("QTabWidget::pane { border: 0; }")
        self.tabWidget.setTabPosition(QtWidgets.QTabWidget.North)
        self.tabWidget.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.tab)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(7)
        self.verticalLayout.setObjectName("verticalLayout")
        self.gvSimulator = SimulatorGraphicsView(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.gvSimulator.sizePolicy().hasHeightForWidth())
        self.gvSimulator.setSizePolicy(sizePolicy)
        self.gvSimulator.setObjectName("gvSimulator")
        self.verticalLayout.addWidget(self.gvSimulator)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.tab_2)
        self.verticalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.tblViewMessage = SimulatorMessageTableView(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.tblViewMessage.sizePolicy().hasHeightForWidth()
        )
        self.tblViewMessage.setSizePolicy(sizePolicy)
        self.tblViewMessage.setAlternatingRowColors(True)
        self.tblViewMessage.setVerticalScrollMode(
            QtWidgets.QAbstractItemView.ScrollPerPixel
        )
        self.tblViewMessage.setHorizontalScrollMode(
            QtWidgets.QAbstractItemView.ScrollPerPixel
        )
        self.tblViewMessage.setShowGrid(False)
        self.tblViewMessage.setObjectName("tblViewMessage")
        self.tblViewMessage.horizontalHeader().setHighlightSections(False)
        self.tblViewMessage.verticalHeader().setHighlightSections(False)
        self.verticalLayout_6.addWidget(self.tblViewMessage)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.lNumSelectedColumns = QtWidgets.QLabel(self.tab_2)
        self.lNumSelectedColumns.setAlignment(
            QtCore.Qt.AlignLeading | QtCore.Qt.AlignLeft | QtCore.Qt.AlignVCenter
        )
        self.lNumSelectedColumns.setObjectName("lNumSelectedColumns")
        self.horizontalLayout_3.addWidget(self.lNumSelectedColumns)
        self.lColumnsSelectedText = QtWidgets.QLabel(self.tab_2)
        self.lColumnsSelectedText.setObjectName("lColumnsSelectedText")
        self.horizontalLayout_3.addWidget(self.lColumnsSelectedText)
        spacerItem = QtWidgets.QSpacerItem(
            138, 33, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum
        )
        self.horizontalLayout_3.addItem(spacerItem)
        self.label_5 = QtWidgets.QLabel(self.tab_2)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_3.addWidget(self.label_5)
        self.cbViewType = QtWidgets.QComboBox(self.tab_2)
        self.cbViewType.setObjectName("cbViewType")
        self.cbViewType.addItem("")
        self.cbViewType.addItem("")
        self.cbViewType.addItem("")
        self.horizontalLayout_3.addWidget(self.cbViewType)
        self.verticalLayout_6.addLayout(self.horizontalLayout_3)
        self.tabWidget.addTab(self.tab_2, "")
        self.tabParticipants = QtWidgets.QWidget()
        self.tabParticipants.setObjectName("tabParticipants")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.tabParticipants)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.tableViewParticipants = ParticipantTableView(self.tabParticipants)
        self.tableViewParticipants.setObjectName("tableViewParticipants")
        self.horizontalLayout.addWidget(self.tableViewParticipants)
        self.verticalLayout_9 = QtWidgets.QVBoxLayout()
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.btnAddParticipant = QtWidgets.QToolButton(self.tabParticipants)
        icon = QtGui.QIcon.fromTheme("list-add")
        self.btnAddParticipant.setIcon(icon)
        self.btnAddParticipant.setObjectName("btnAddParticipant")
        self.verticalLayout_9.addWidget(self.btnAddParticipant)
        self.btnRemoveParticipant = QtWidgets.QToolButton(self.tabParticipants)
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnRemoveParticipant.setIcon(icon)
        self.btnRemoveParticipant.setObjectName("btnRemoveParticipant")
        self.verticalLayout_9.addWidget(self.btnRemoveParticipant)
        self.btnUp = QtWidgets.QToolButton(self.tabParticipants)
        icon = QtGui.QIcon.fromTheme("go-up")
        self.btnUp.setIcon(icon)
        self.btnUp.setObjectName("btnUp")
        self.verticalLayout_9.addWidget(self.btnUp)
        self.btnDown = QtWidgets.QToolButton(self.tabParticipants)
        icon = QtGui.QIcon.fromTheme("go-down")
        self.btnDown.setIcon(icon)
        self.btnDown.setObjectName("btnDown")
        self.verticalLayout_9.addWidget(self.btnDown)
        spacerItem1 = QtWidgets.QSpacerItem(
            20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
        )
        self.verticalLayout_9.addItem(spacerItem1)
        self.horizontalLayout.addLayout(self.verticalLayout_9)
        self.tabWidget.addTab(self.tabParticipants, "")
        self.verticalLayout_2.addWidget(self.tabWidget)
        self.layoutWidget_3 = QtWidgets.QWidget(self.splitter)
        self.layoutWidget_3.setObjectName("layoutWidget_3")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.layoutWidget_3)
        self.verticalLayout_4.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.lblMsgFieldsValues = QtWidgets.QLabel(self.layoutWidget_3)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.lblMsgFieldsValues.sizePolicy().hasHeightForWidth()
        )
        self.lblMsgFieldsValues.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.lblMsgFieldsValues.setFont(font)
        self.lblMsgFieldsValues.setAlignment(QtCore.Qt.AlignCenter)
        self.lblMsgFieldsValues.setObjectName("lblMsgFieldsValues")
        self.verticalLayout_4.addWidget(self.lblMsgFieldsValues)
        self.detail_view_widget = QtWidgets.QStackedWidget(self.layoutWidget_3)
        self.detail_view_widget.setObjectName("detail_view_widget")
        self.page_empty = QtWidgets.QWidget()
        self.page_empty.setObjectName("page_empty")
        self.detail_view_widget.addWidget(self.page_empty)
        self.page_goto_action = QtWidgets.QWidget()
        self.page_goto_action.setObjectName("page_goto_action")
        self.verticalLayout_7 = QtWidgets.QGridLayout(self.page_goto_action)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.label_9 = QtWidgets.QLabel(self.page_goto_action)
        self.label_9.setObjectName("label_9")
        self.verticalLayout_7.addWidget(self.label_9, 0, 0, 1, 1)
        self.goto_combobox = QtWidgets.QComboBox(self.page_goto_action)
        self.goto_combobox.setObjectName("goto_combobox")
        self.verticalLayout_7.addWidget(self.goto_combobox, 0, 1, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(
            40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum
        )
        self.verticalLayout_7.addItem(spacerItem2, 0, 2, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(
            20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
        )
        self.verticalLayout_7.addItem(spacerItem3, 1, 0, 1, 3)
        self.detail_view_widget.addWidget(self.page_goto_action)
        self.page_message = QtWidgets.QWidget()
        self.page_message.setObjectName("page_message")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.page_message)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.label_10 = QtWidgets.QLabel(self.page_message)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_10.sizePolicy().hasHeightForWidth())
        self.label_10.setSizePolicy(sizePolicy)
        self.label_10.setObjectName("label_10")
        self.gridLayout_6.addWidget(self.label_10, 1, 0, 1, 1)
        self.tblViewFieldValues = SimulatorLabelTableView(self.page_message)
        self.tblViewFieldValues.setAlternatingRowColors(True)
        self.tblViewFieldValues.setShowGrid(False)
        self.tblViewFieldValues.setObjectName("tblViewFieldValues")
        self.tblViewFieldValues.horizontalHeader().setDefaultSectionSize(150)
        self.tblViewFieldValues.horizontalHeader().setStretchLastSection(True)
        self.tblViewFieldValues.verticalHeader().setVisible(False)
        self.gridLayout_6.addWidget(self.tblViewFieldValues, 2, 2, 1, 1)
        self.label_11 = QtWidgets.QLabel(self.page_message)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_11.sizePolicy().hasHeightForWidth())
        self.label_11.setSizePolicy(sizePolicy)
        self.label_11.setAlignment(
            QtCore.Qt.AlignLeading | QtCore.Qt.AlignLeft | QtCore.Qt.AlignTop
        )
        self.label_11.setObjectName("label_11")
        self.gridLayout_6.addWidget(self.label_11, 2, 0, 1, 1)
        self.spinBoxRepeat = QtWidgets.QSpinBox(self.page_message)
        self.spinBoxRepeat.setMinimum(1)
        self.spinBoxRepeat.setObjectName("spinBoxRepeat")
        self.gridLayout_6.addWidget(self.spinBoxRepeat, 1, 2, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.page_message)
        self.label_2.setObjectName("label_2")
        self.gridLayout_6.addWidget(self.label_2, 0, 0, 1, 1)
        self.lblEncodingDecoding = QtWidgets.QLabel(self.page_message)
        self.lblEncodingDecoding.setObjectName("lblEncodingDecoding")
        self.gridLayout_6.addWidget(self.lblEncodingDecoding, 0, 2, 1, 1)
        self.detail_view_widget.addWidget(self.page_message)
        self.page_rule = QtWidgets.QWidget()
        self.page_rule.setObjectName("page_rule")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.page_rule)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label_12 = QtWidgets.QLabel(self.page_rule)
        self.label_12.setObjectName("label_12")
        self.gridLayout_3.addWidget(self.label_12, 0, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(
            20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
        )
        self.gridLayout_3.addItem(spacerItem4, 1, 0, 1, 2)
        self.ruleCondLineEdit = ExpressionLineEdit(self.page_rule)
        self.ruleCondLineEdit.setObjectName("ruleCondLineEdit")
        self.gridLayout_3.addWidget(self.ruleCondLineEdit, 0, 1, 1, 1)
        self.detail_view_widget.addWidget(self.page_rule)
        self.page_ext_prog_action = QtWidgets.QWidget()
        self.page_ext_prog_action.setObjectName("page_ext_prog_action")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.page_ext_prog_action)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.checkBoxPassTranscriptSTDIN = QtWidgets.QCheckBox(
            self.page_ext_prog_action
        )
        self.checkBoxPassTranscriptSTDIN.setObjectName("checkBoxPassTranscriptSTDIN")
        self.gridLayout_9.addWidget(self.checkBoxPassTranscriptSTDIN, 2, 0, 1, 4)
        self.label_14 = QtWidgets.QLabel(self.page_ext_prog_action)
        self.label_14.setObjectName("label_14")
        self.gridLayout_9.addWidget(self.label_14, 1, 0, 1, 1)
        self.lineEditTriggerCommand = QtWidgets.QLineEdit(self.page_ext_prog_action)
        self.lineEditTriggerCommand.setReadOnly(False)
        self.lineEditTriggerCommand.setObjectName("lineEditTriggerCommand")
        self.gridLayout_9.addWidget(self.lineEditTriggerCommand, 1, 1, 1, 1)
        self.btnChooseCommand = QtWidgets.QToolButton(self.page_ext_prog_action)
        self.btnChooseCommand.setObjectName("btnChooseCommand")
        self.gridLayout_9.addWidget(self.btnChooseCommand, 1, 2, 1, 2)
        spacerItem5 = QtWidgets.QSpacerItem(
            20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
        )
        self.gridLayout_9.addItem(spacerItem5, 4, 0, 1, 4)
        self.label_18 = QtWidgets.QLabel(self.page_ext_prog_action)
        self.label_18.setWordWrap(True)
        self.label_18.setObjectName("label_18")
        self.gridLayout_9.addWidget(self.label_18, 3, 0, 1, 4)
        self.detail_view_widget.addWidget(self.page_ext_prog_action)
        self.page_sleep = QtWidgets.QWidget()
        self.page_sleep.setObjectName("page_sleep")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.page_sleep)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_13 = QtWidgets.QLabel(self.page_sleep)
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_2.addWidget(self.label_13)
        self.doubleSpinBoxSleep = QtWidgets.QDoubleSpinBox(self.page_sleep)
        self.doubleSpinBoxSleep.setDecimals(6)
        self.doubleSpinBoxSleep.setMaximum(10000.0)
        self.doubleSpinBoxSleep.setProperty("value", 1.0)
        self.doubleSpinBoxSleep.setObjectName("doubleSpinBoxSleep")
        self.horizontalLayout_2.addWidget(self.doubleSpinBoxSleep)
        self.verticalLayout_10.addLayout(self.horizontalLayout_2)
        spacerItem6 = QtWidgets.QSpacerItem(
            20, 231, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
        )
        self.verticalLayout_10.addItem(spacerItem6)
        self.detail_view_widget.addWidget(self.page_sleep)
        self.page = QtWidgets.QWidget()
        self.page.setObjectName("page")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.page)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.spinBoxCounterStep = QtWidgets.QSpinBox(self.page)
        self.spinBoxCounterStep.setMinimum(1)
        self.spinBoxCounterStep.setMaximum(999999)
        self.spinBoxCounterStep.setObjectName("spinBoxCounterStep")
        self.gridLayout_2.addWidget(self.spinBoxCounterStep, 2, 1, 1, 1)
        self.label_15 = QtWidgets.QLabel(self.page)
        self.label_15.setObjectName("label_15")
        self.gridLayout_2.addWidget(self.label_15, 1, 0, 1, 1)
        self.label_16 = QtWidgets.QLabel(self.page)
        self.label_16.setObjectName("label_16")
        self.gridLayout_2.addWidget(self.label_16, 2, 0, 1, 1)
        self.spinBoxCounterStart = QtWidgets.QSpinBox(self.page)
        self.spinBoxCounterStart.setMaximum(999999)
        self.spinBoxCounterStart.setObjectName("spinBoxCounterStart")
        self.gridLayout_2.addWidget(self.spinBoxCounterStart, 1, 1, 1, 1)
        self.verticalLayout_11.addLayout(self.gridLayout_2)
        self.label_17 = QtWidgets.QLabel(self.page)
        self.label_17.setWordWrap(True)
        self.label_17.setObjectName("label_17")
        self.verticalLayout_11.addWidget(self.label_17)
        spacerItem7 = QtWidgets.QSpacerItem(
            20, 36, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
        )
        self.verticalLayout_11.addItem(spacerItem7)
        self.detail_view_widget.addWidget(self.page)
        self.verticalLayout_4.addWidget(self.detail_view_widget)
        self.verticalLayout_5.addWidget(self.splitterLeftRight)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.verticalLayout_8.addWidget(self.scrollArea)

        self.retranslateUi(SimulatorTab)
        self.tabWidget.setCurrentIndex(0)
        self.detail_view_widget.setCurrentIndex(2)

    def retranslateUi(self, SimulatorTab):
        _translate = QtCore.QCoreApplication.translate
        SimulatorTab.setWindowTitle(_translate("SimulatorTab", "Form"))
        self.label.setText(
            _translate("SimulatorTab", "Protocols (Drag&Drop to Flow Graph):")
        )
        self.label_6.setText(_translate("SimulatorTab", "Simulate these participants:"))
        self.label_4.setText(
            _translate("SimulatorTab", "Repeat simulation this often:")
        )
        self.spinBoxNRepeat.setSpecialValueText(_translate("SimulatorTab", "Infinite"))
        self.label_3.setText(_translate("SimulatorTab", "Timeout:"))
        self.spinBoxTimeout.setSuffix(_translate("SimulatorTab", "ms"))
        self.label_7.setText(
            _translate("SimulatorTab", "In case of an overdue response:")
        )
        self.comboBoxError.setItemText(
            0, _translate("SimulatorTab", "Resend last message")
        )
        self.comboBoxError.setItemText(1, _translate("SimulatorTab", "Stop simulation"))
        self.comboBoxError.setItemText(
            2, _translate("SimulatorTab", "Restart simulation")
        )
        self.label_8.setText(_translate("SimulatorTab", "Maximum retries:"))
        self.btnStartSim.setText(_translate("SimulatorTab", "Simulate..."))
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.tab), _translate("SimulatorTab", "Flow Graph")
        )
        self.lNumSelectedColumns.setText(_translate("SimulatorTab", "0"))
        self.lColumnsSelectedText.setText(
            _translate("SimulatorTab", "column(s) selected")
        )
        self.label_5.setText(_translate("SimulatorTab", "Viewtype:"))
        self.cbViewType.setItemText(0, _translate("SimulatorTab", "Bit"))
        self.cbViewType.setItemText(1, _translate("SimulatorTab", "Hex"))
        self.cbViewType.setItemText(2, _translate("SimulatorTab", "ASCII"))
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.tab_2), _translate("SimulatorTab", "Messages")
        )
        self.btnAddParticipant.setToolTip(_translate("SimulatorTab", "Add participant"))
        self.btnAddParticipant.setText(_translate("SimulatorTab", "Add"))
        self.btnRemoveParticipant.setToolTip(
            _translate("SimulatorTab", "Remove participant")
        )
        self.btnRemoveParticipant.setText(_translate("SimulatorTab", "Remove"))
        self.btnUp.setToolTip(
            _translate("SimulatorTab", "Move selected participants up")
        )
        self.btnUp.setText(_translate("SimulatorTab", "..."))
        self.btnDown.setToolTip(
            _translate("SimulatorTab", "Move selected participants down")
        )
        self.btnDown.setText(_translate("SimulatorTab", "..."))
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.tabParticipants),
            _translate("SimulatorTab", "Participants"),
        )
        self.lblMsgFieldsValues.setText(
            _translate("SimulatorTab", "Detail view for item")
        )
        self.label_9.setText(_translate("SimulatorTab", "Goto:"))
        self.label_10.setText(_translate("SimulatorTab", "Copies:"))
        self.label_11.setText(_translate("SimulatorTab", "Labels:"))
        self.label_2.setText(_translate("SimulatorTab", "Coding:"))
        self.lblEncodingDecoding.setText(_translate("SimulatorTab", "-"))
        self.label_12.setText(_translate("SimulatorTab", "Condition:"))
        self.ruleCondLineEdit.setPlaceholderText(
            _translate("SimulatorTab", "not (item1.crc == 0b1010 and item2.length >=3)")
        )
        self.checkBoxPassTranscriptSTDIN.setText(
            _translate("SimulatorTab", "Pass transcript to STDIN")
        )
        self.label_14.setText(_translate("SimulatorTab", "Command:"))
        self.lineEditTriggerCommand.setPlaceholderText(
            _translate(
                "SimulatorTab",
                "Path [+arguments] to external command e.g. mail or sendsms",
            )
        )
        self.btnChooseCommand.setText(_translate("SimulatorTab", "..."))
        self.label_18.setText(
            _translate(
                "SimulatorTab",
                '<html><head/><body><p>You can access the return code of this item in formulas and rules using the item identifier followed by <span style=" font-style:italic;">.rc</span> e.g.<span style=" font-style:italic;"> item5.rc</span>.</p></body></html>',
            )
        )
        self.label_13.setText(_translate("SimulatorTab", "Sleep for:"))
        self.doubleSpinBoxSleep.setSuffix(_translate("SimulatorTab", "s"))
        self.label_15.setText(_translate("SimulatorTab", "Start:"))
        self.label_16.setText(_translate("SimulatorTab", "Step:"))
        self.label_17.setText(
            _translate(
                "SimulatorTab",
                '<html><head/><body><p>This counter will increase by <span style=" font-weight:600;">step</span> each time it gets hit during simulation. It will preserve it\'s value during simulation repeats and retries. To reset all counters stop the simulation and start it again.</p><p>Access the value of this counter using item&lt;Number&gt;.counter_value in <span style=" font-weight:600;">Formulas</span> or as parameter in <span style=" font-weight:600;">external programs</span> e.g. <span style=" font-style:italic;">external_py -c item5.counter_value</span>. The value of this counter will be inserted during simulation time.</p></body></html>',
            )
        )


from urh.ui.ExpressionLineEdit import ExpressionLineEdit
from urh.ui.views.GeneratorTreeView import GeneratorTreeView
from urh.ui.views.ParticipantTableView import ParticipantTableView
from urh.ui.views.SimulatorGraphicsView import SimulatorGraphicsView
from urh.ui.views.SimulatorLabelTableView import SimulatorLabelTableView
from urh.ui.views.SimulatorMessageTableView import SimulatorMessageTableView
from . import urh_rc



import sys

from PyQt5.QtCore import QModelIndex, Qt, QAbstractItemModel, pyqtSlot, QRectF
from PyQt5.QtGui import QImage, QPainter, QColor, QPixmap
from PyQt5.QtWidgets import (
    QStyledItemDelegate,
    QWidget,
    QStyleOptionViewItem,
    QComboBox,
)


class ComboBoxDelegate(QStyledItemDelegate):
    def __init__(
        self, items, colors=None, is_editable=False, return_index=True, parent=None
    ):
        """

        :param items:
        :param colors:
        :param is_editable:
        :param return_index: True for returning current index, false for returning current text of editor
        :param parent:
        """
        super().__init__(parent)
        self.items = items
        self.colors = colors
        self.return_index = return_index
        self.is_editable = is_editable
        self.current_edit_text = ""

        if colors:
            assert len(items) == len(colors)

    def paint(
        self, painter: QPainter, option: QStyleOptionViewItem, index: QModelIndex
    ):
        if self.colors:
            try:
                item = index.model().data(index)
                index = self.items.index(item) if item in self.items else int(item)
                color = self.colors[index]

                x, y, h = option.rect.x(), option.rect.y(), option.rect.height()

                rect = QRectF(x + 8, y + h / 2 - 8, 16, 16)
                painter.fillRect(rect, QColor("black"))
                rect = rect.adjusted(1, 1, -1, -1)
                painter.fillRect(
                    rect, QColor(color.red(), color.green(), color.blue(), 255)
                )
            except:
                super().paint(painter, option, index)
        else:
            super().paint(painter, option, index)

    def createEditor(
        self, parent: QWidget, option: QStyleOptionViewItem, index: QModelIndex
    ):
        editor = QComboBox(parent)
        if sys.platform == "win32":
            # Ensure text entries are visible with windows combo boxes
            editor.setMinimumHeight(self.sizeHint(option, index).height() + 10)

        editor.addItems(self.items)

        if self.is_editable:
            editor.setEditable(True)
            editor.setInsertPolicy(QComboBox.NoInsert)

        if self.current_edit_text:
            editor.setEditText(self.current_edit_text)

        if self.colors:
            img = QImage(16, 16, QImage.Format_RGB32)
            painter = QPainter(img)

            painter.fillRect(img.rect(), Qt.black)
            rect = img.rect().adjusted(1, 1, -1, -1)
            for i, item in enumerate(self.items):
                color = self.colors[i]
                painter.fillRect(
                    rect, QColor(color.red(), color.green(), color.blue(), 255)
                )
                editor.setItemData(i, QPixmap.fromImage(img), Qt.DecorationRole)

            del painter
        editor.currentIndexChanged.connect(self.currentIndexChanged)
        editor.editTextChanged.connect(self.on_edit_text_changed)
        return editor

    def setEditorData(self, editor: QWidget, index: QModelIndex):
        editor.blockSignals(True)
        item = index.model().data(index)
        try:
            indx = self.items.index(item) if item in self.items else int(item)
            editor.setCurrentIndex(indx)
        except ValueError:
            pass
        editor.blockSignals(False)

    def setModelData(
        self, editor: QWidget, model: QAbstractItemModel, index: QModelIndex
    ):
        if self.return_index:
            model.setData(index, editor.currentIndex(), Qt.EditRole)
        else:
            model.setData(index, editor.currentText(), Qt.EditRole)

    def updateEditorGeometry(
        self, editor: QWidget, option: QStyleOptionViewItem, index: QModelIndex
    ):
        editor.setGeometry(option.rect)

    @pyqtSlot()
    def currentIndexChanged(self):
        self.commitData.emit(self.sender())

    @pyqtSlot(str)
    def on_edit_text_changed(self, text: str):
        self.current_edit_text = text



from collections import defaultdict

import numpy as np

from urh.awre.CommonRange import CommonRange
from urh.cythonext import awre_util


class Histogram(object):
    """
    Create a histogram based on the equalness of vectors
    """

    def __init__(self, vectors, indices=None, normalize=True, debug=False):
        """

        :type vectors: list of np.ndarray
        :param indices: Indices of vectors for which the Histogram shall be created.
                        This is useful for clustering.
                        If None Histogram will be created over all bitvectors
        :type: list of int
        :param normalize:
        """
        self.__vectors = vectors  # type: list[np.ndarray]
        self.__active_indices = (
            list(range(len(vectors))) if indices is None else indices
        )

        self.normalize = normalize
        self.data = self.__create_histogram()

    def __create_histogram(self):
        return awre_util.create_difference_histogram(
            self.__vectors, self.__active_indices
        )

    def __repr__(self):
        return str(self.data.tolist())

    def find_common_ranges(self, alpha=0.95, range_type="bit"):
        """
        Find all common ranges where at least alpha percent of numbers are equal

        :param range_type: on of bit/hex/byte
        :param alpha:
        :return:
        """
        data_indices = np.argwhere(self.data >= alpha).flatten()

        if len(data_indices) < 2:
            return []

        result = []
        start, length = None, 0
        for i in range(1, len(data_indices)):
            if start is None:
                start = data_indices[i - 1]
                length = 1

            if data_indices[i] - data_indices[i - 1] == 1:
                length += 1
            else:
                if length >= 2:
                    value = self.__get_value_for_common_range(start, length)
                    result.append(
                        CommonRange(
                            start,
                            length,
                            value,
                            message_indices=set(self.__active_indices),
                            range_type=range_type,
                        )
                    )

                start, length = None, 0

            if i == len(data_indices) - 1 and length >= 2:
                value = self.__get_value_for_common_range(start, length)
                result.append(
                    CommonRange(
                        start,
                        length,
                        value,
                        message_indices=set(self.__active_indices),
                        range_type=range_type,
                    )
                )

        return result

    def __get_value_for_common_range(self, start: int, length: int):
        """
        Get the value for a range of common numbers. This is the value that appears most.

        :param start: Start of the common bit range
        :param length: Length of the common bit range
        :return:
        """
        values = defaultdict(list)
        for i in self.__active_indices:
            vector = self.__vectors[i]
            values[vector[start : start + length].tostring()].append(i)
        value = max(values, key=lambda x: len(x))
        indices = values[value]
        return self.__vectors[indices[0]][start : start + length]

    def __vector_to_string(self, data_vector) -> str:
        lut = {i: "{0:x}".format(i) for i in range(16)}
        return "".join(lut[x] if x in lut else " {} ".format(x) for x in data_vector)

    def plot(self):
        import matplotlib.pyplot as plt

        self.subplot_on(plt)
        plt.show()

    def subplot_on(self, plt):
        plt.grid()
        plt.plot(self.data)
        plt.xticks(np.arange(4, len(self.data), 4))
        plt.xlabel("Bit position")
        if self.normalize:
            plt.ylabel("Number common bits (normalized)")
        else:
            plt.ylabel("Number common bits")
        plt.ylim(ymin=0)


if __name__ == "__main__":
    bv1 = np.array([1, 0, 1, 0, 1, 1, 1, 1], dtype=np.int8)
    bv2 = np.array([1, 0, 1, 0, 1, 0, 0, 0], dtype=np.int8)
    bv3 = np.array([1, 0, 1, 0, 1, 1, 1, 1], dtype=np.int8)
    bv4 = np.array([1, 0, 1, 0, 0, 0, 0, 0], dtype=np.int8)
    h = Histogram([bv1, bv2, bv3, bv4])
    h.plot()



from collections import OrderedDict
from multiprocessing.connection import Connection

import numpy as np

from urh.dev.native.Device import Device
from urh.dev.native.lib import sdrplay
from urh.util.Logger import logger


class SDRPlay(Device):
    DEVICE_LIB = sdrplay
    ASYNCHRONOUS = True
    DEVICE_METHODS = Device.DEVICE_METHODS.copy()
    DEVICE_METHODS[Device.Command.SET_RF_GAIN.name] = "set_gain"
    DEVICE_METHODS[Device.Command.SET_IF_GAIN.name]["rx"] = "set_if_gain"
    DEVICE_METHODS[Device.Command.SET_ANTENNA_INDEX.name] = "set_antenna"

    DATA_TYPE = np.int16

    def __init__(
        self,
        center_freq,
        sample_rate,
        bandwidth,
        gain,
        if_gain=1,
        baseband_gain=1,
        resume_on_full_receive_buffer=False,
    ):
        super().__init__(
            center_freq=center_freq,
            sample_rate=sample_rate,
            bandwidth=bandwidth,
            gain=gain,
            if_gain=if_gain,
            baseband_gain=baseband_gain,
            resume_on_full_receive_buffer=resume_on_full_receive_buffer,
        )
        self.success = 0
        self.error_codes = {
            0: "SUCCESS",
            1: "FAIL",
            2: "INVALID PARAMETER",
            3: "OUT OF RANGE",
            4: "GAIN UPDATE ERROR",
            5: "RF UPDATE ERROR",
            6: "FS UPDATE ERROR",
            7: "HARDWARE ERROR",
            8: "ALIASING ERROR",
            9: "ALREADY INITIALIZED",
            10: "NOT INITIALIZED",
            11: "NOT ENABLED",
            12: "HARDWARE VERSION ERROR",
            13: "OUT OF MEMORY ERROR",
        }

    @staticmethod
    def device_dict_to_string(d):
        hw_ver = d["hw_version"]
        serial = d["serial"]
        return "RSP {} ({})".format(hw_ver, serial)

    @property
    def device_parameters(self):
        return OrderedDict(
            [
                (self.Command.SET_ANTENNA_INDEX.name, self.antenna_index),
                (self.Command.SET_FREQUENCY.name, self.frequency),
                (self.Command.SET_SAMPLE_RATE.name, self.sample_rate),
                (self.Command.SET_BANDWIDTH.name, self.bandwidth),
                (self.Command.SET_RF_GAIN.name, self.gain),
                (self.Command.SET_IF_GAIN.name, self.if_gain),
                ("identifier", self.device_number),
            ]
        )

    @property
    def has_multi_device_support(self):
        return True

    @classmethod
    def get_device_list(cls):
        return [cls.device_dict_to_string(d) for d in sdrplay.get_devices()]

    @classmethod
    def enter_async_receive_mode(
        cls, data_connection: Connection, ctrl_connection: Connection
    ):
        ret = sdrplay.init_stream(
            cls.sdrplay_initial_gain,
            cls.sdrplay_initial_sample_rate,
            cls.sdrplay_initial_freq,
            cls.sdrplay_initial_bandwidth,
            cls.sdrplay_initial_if_gain,
            data_connection,
        )

        ctrl_connection.send(
            "Start RX MODE with \n  FREQUENCY={}\n  SAMPLE_RATE={}\n  BANDWIDTH={}\n  GAIN={}\n  IF_GAIN={}:{}".format(
                cls.sdrplay_initial_freq,
                cls.sdrplay_initial_sample_rate,
                cls.sdrplay_initial_bandwidth,
                cls.sdrplay_initial_gain,
                cls.sdrplay_initial_if_gain,
                ret,
            )
        )

        return ret

    @classmethod
    def init_device(
        cls, ctrl_connection: Connection, is_tx: bool, parameters: OrderedDict
    ) -> bool:
        identifier = parameters["identifier"]

        try:
            device_list = sdrplay.get_devices()
            device_number = int(identifier)
            ctrl_connection.send(
                "CONNECTED DEVICES: {}".format(
                    ", ".join(map(cls.device_dict_to_string, device_list))
                )
            )
            ret = sdrplay.set_device_index(device_number)
            ctrl_connection.send(
                "SET DEVICE NUMBER to {}:{}".format(device_number, ret)
            )
        except (TypeError, ValueError) as e:
            logger.exception(e)
            return False

        device_model = device_list[device_number]["hw_version"]
        sdrplay.set_gr_mode_for_dev_model(device_model)
        if device_model == 2:
            antenna = parameters[cls.Command.SET_ANTENNA_INDEX.name]
            cls.process_command(
                (cls.Command.SET_ANTENNA_INDEX.name, antenna),
                ctrl_connection,
                is_tx=False,
            )
        else:
            ctrl_connection.send("Skipping antenna selection for RSP1 device")

        cls.sdrplay_initial_freq = parameters[cls.Command.SET_FREQUENCY.name]
        cls.sdrplay_initial_sample_rate = parameters[cls.Command.SET_SAMPLE_RATE.name]
        cls.sdrplay_initial_bandwidth = parameters[cls.Command.SET_BANDWIDTH.name]
        cls.sdrplay_initial_gain = parameters[cls.Command.SET_RF_GAIN.name]
        cls.sdrplay_initial_if_gain = parameters[cls.Command.SET_IF_GAIN.name]
        cls.sdrplay_device_index = identifier
        return True

    @classmethod
    def shutdown_device(cls, ctrl_connection, is_tx: bool):
        logger.debug("SDRPLAY: closing device")
        ret = sdrplay.close_stream()
        ctrl_connection.send("CLOSE STREAM:" + str(ret))

        if cls.sdrplay_device_index is not None:
            ret = sdrplay.release_device_index()
            ctrl_connection.send("RELEASE DEVICE:" + str(ret))

    @staticmethod
    def bytes_to_iq(buffer):
        return np.frombuffer(buffer, dtype=np.int16).reshape((-1, 2), order="C")



from PyQt5.QtCore import Qt
from PyQt5.QtGui import QKeySequence, QIcon
from PyQt5.QtWidgets import QTableView, QMenu, QAction, QActionGroup

from urh.models.PLabelTableModel import PLabelTableModel
from urh.models.SimulatorMessageFieldModel import SimulatorMessageFieldModel
from urh.simulator.SimulatorProtocolLabel import SimulatorProtocolLabel


class ProtocolLabelTableView(QTableView):
    def __init__(self, parent=None):
        super().__init__(parent)

        self.delete_action = QAction("Delete selected labels", self)
        self.delete_action.setShortcut(QKeySequence.Delete)
        self.delete_action.setIcon(QIcon.fromTheme("edit-delete"))
        self.delete_action.setShortcutContext(Qt.WidgetWithChildrenShortcut)
        self.delete_action.triggered.connect(self.delete_selected_rows)
        self.addAction(self.delete_action)

    @property
    def selected_rows(self) -> list:
        return [i.row() for i in self.selectedIndexes()]

    def model(self) -> PLabelTableModel:
        return super().model()

    def create_context_menu(self):
        menu = QMenu(self)
        if self.model().rowCount() == 0:
            return menu

        if isinstance(self.model(), SimulatorMessageFieldModel):
            value_type_group = QActionGroup(self)
            value_type_menu = menu.addMenu("Set value type")
            labels = [
                self.model().message_type[i]
                for i in self.selected_rows
                if not self.model().message_type[i].is_checksum_label
            ]

            for i, value_type in enumerate(SimulatorProtocolLabel.VALUE_TYPES):
                va = value_type_menu.addAction(value_type)
                va.setCheckable(True)
                va.setActionGroup(value_type_group)
                va.setData(i)

                if all(lbl.value_type_index == i for lbl in labels):
                    va.setChecked(True)

                va.triggered.connect(self.on_set_value_type_action_triggered)

        menu.addAction(self.delete_action)
        return menu

    def contextMenuEvent(self, event):
        self.create_context_menu().exec_(self.mapToGlobal(event.pos()))

    def delete_selected_rows(self):
        for row in sorted(self.selected_rows, reverse=True):
            self.model().remove_label_at(row)

    def on_set_value_type_action_triggered(self):
        assert isinstance(self.model(), SimulatorMessageFieldModel)
        value_type_index = self.sender().data()
        self.model().set_value_type_index(self.selected_rows, value_type_index)



# -*- coding: utf-8 -*-

#
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_TabAnalysis(object):
    def setupUi(self, TabAnalysis):
        TabAnalysis.setObjectName("TabAnalysis")
        TabAnalysis.resize(1331, 739)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(TabAnalysis.sizePolicy().hasHeightForWidth())
        TabAnalysis.setSizePolicy(sizePolicy)
        TabAnalysis.setFocusPolicy(QtCore.Qt.ClickFocus)
        TabAnalysis.setAcceptDrops(True)
        TabAnalysis.setProperty("lineWidth", 1)
        TabAnalysis.setProperty("midLineWidth", 0)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(TabAnalysis)
        self.verticalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_7.setSpacing(0)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.scrollArea = QtWidgets.QScrollArea(TabAnalysis)
        self.scrollArea.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.scrollArea.setLineWidth(0)
        self.scrollArea.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 1331, 739))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.splitter_2 = QtWidgets.QSplitter(self.scrollAreaWidgetContents)
        self.splitter_2.setStyleSheet(
            "QSplitter::handle:vertical {\n"
            "margin: 4px 0px;\n"
            "    background-color: qlineargradient(x1:0, y1:0, x2:1, y2:0, \n"
            "stop:0 rgba(255, 255, 255, 0), \n"
            "stop:0.5 rgba(100, 100, 100, 100), \n"
            "stop:1 rgba(255, 255, 255, 0));\n"
            "image: url(:/icons/icons/splitter_handle_horizontal.svg);\n"
            "}"
        )
        self.splitter_2.setOrientation(QtCore.Qt.Vertical)
        self.splitter_2.setHandleWidth(6)
        self.splitter_2.setObjectName("splitter_2")
        self.splitter = QtWidgets.QSplitter(self.splitter_2)
        self.splitter.setStyleSheet(
            "QSplitter::handle:horizontal {\n"
            "margin: 4px 0px;\n"
            "    background-color: qlineargradient(x1:0, y1:0, x2:0, y2:1, \n"
            "stop:0 rgba(255, 255, 255, 0), \n"
            "stop:0.5 rgba(100, 100, 100, 100), \n"
            "stop:1 rgba(255, 255, 255, 0));\n"
            "image: url(:/icons/icons/splitter_handle_vertical.svg);\n"
            "}"
        )
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setHandleWidth(6)
        self.splitter.setObjectName("splitter")
        self.layoutWidget = QtWidgets.QWidget(self.splitter)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout_2.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.tabWidget = QtWidgets.QTabWidget(self.layoutWidget)
        self.tabWidget.setStyleSheet("QTabWidget::pane { border: 0; }")
        self.tabWidget.setObjectName("tabWidget")
        self.tab_protocols = QtWidgets.QWidget()
        self.tab_protocols.setObjectName("tab_protocols")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.tab_protocols)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setSpacing(7)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.treeViewProtocols = ProtocolTreeView(self.tab_protocols)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.treeViewProtocols.sizePolicy().hasHeightForWidth()
        )
        self.treeViewProtocols.setSizePolicy(sizePolicy)
        self.treeViewProtocols.setAcceptDrops(True)
        self.treeViewProtocols.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.treeViewProtocols.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.treeViewProtocols.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.treeViewProtocols.setDragEnabled(True)
        self.treeViewProtocols.setDragDropOverwriteMode(False)
        self.treeViewProtocols.setDragDropMode(QtWidgets.QAbstractItemView.DragDrop)
        self.treeViewProtocols.setDefaultDropAction(QtCore.Qt.IgnoreAction)
        self.treeViewProtocols.setSelectionMode(
            QtWidgets.QAbstractItemView.SingleSelection
        )
        self.treeViewProtocols.setSelectionBehavior(
            QtWidgets.QAbstractItemView.SelectRows
        )
        self.treeViewProtocols.setTextElideMode(QtCore.Qt.ElideRight)
        self.treeViewProtocols.setAnimated(True)
        self.treeViewProtocols.setObjectName("treeViewProtocols")
        self.treeViewProtocols.header().setVisible(False)
        self.treeViewProtocols.header().setCascadingSectionResizes(False)
        self.treeViewProtocols.header().setStretchLastSection(True)
        self.verticalLayout_3.addWidget(self.treeViewProtocols)
        self.tabWidget.addTab(self.tab_protocols, "")
        self.tab_participants = QtWidgets.QWidget()
        self.tab_participants.setObjectName("tab_participants")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.tab_participants)
        self.verticalLayout_11.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.listViewParticipants = QtWidgets.QListView(self.tab_participants)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.listViewParticipants.sizePolicy().hasHeightForWidth()
        )
        self.listViewParticipants.setSizePolicy(sizePolicy)
        self.listViewParticipants.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.listViewParticipants.setTextElideMode(QtCore.Qt.ElideRight)
        self.listViewParticipants.setObjectName("listViewParticipants")
        self.verticalLayout_11.addWidget(self.listViewParticipants)
        self.tabWidget.addTab(self.tab_participants, "")
        self.verticalLayout_2.addWidget(self.tabWidget)
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label_5 = QtWidgets.QLabel(self.layoutWidget)
        self.label_5.setObjectName("label_5")
        self.gridLayout_3.addWidget(self.label_5, 1, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.layoutWidget)
        self.label_4.setObjectName("label_4")
        self.gridLayout_3.addWidget(self.label_4, 0, 0, 1, 1)
        self.lEncodingErrors = QtWidgets.QLabel(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.lEncodingErrors.sizePolicy().hasHeightForWidth()
        )
        self.lEncodingErrors.setSizePolicy(sizePolicy)
        self.lEncodingErrors.setObjectName("lEncodingErrors")
        self.gridLayout_3.addWidget(self.lEncodingErrors, 2, 0, 1, 1)
        self.cbDecoding = QtWidgets.QComboBox(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cbDecoding.sizePolicy().hasHeightForWidth())
        self.cbDecoding.setSizePolicy(sizePolicy)
        self.cbDecoding.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContents)
        self.cbDecoding.setObjectName("cbDecoding")
        self.cbDecoding.addItem("")
        self.cbDecoding.addItem("")
        self.cbDecoding.addItem("")
        self.cbDecoding.addItem("")
        self.cbDecoding.addItem("")
        self.gridLayout_3.addWidget(self.cbDecoding, 1, 1, 1, 1)
        self.chkBoxShowOnlyDiffs = QtWidgets.QCheckBox(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.chkBoxShowOnlyDiffs.sizePolicy().hasHeightForWidth()
        )
        self.chkBoxShowOnlyDiffs.setSizePolicy(sizePolicy)
        self.chkBoxShowOnlyDiffs.setObjectName("chkBoxShowOnlyDiffs")
        self.gridLayout_3.addWidget(self.chkBoxShowOnlyDiffs, 4, 0, 1, 2)
        self.cbProtoView = QtWidgets.QComboBox(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cbProtoView.sizePolicy().hasHeightForWidth())
        self.cbProtoView.setSizePolicy(sizePolicy)
        self.cbProtoView.setObjectName("cbProtoView")
        self.cbProtoView.addItem("")
        self.cbProtoView.addItem("")
        self.cbProtoView.addItem("")
        self.gridLayout_3.addWidget(self.cbProtoView, 0, 1, 1, 1)
        self.lDecodingErrorsValue = QtWidgets.QLabel(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.lDecodingErrorsValue.sizePolicy().hasHeightForWidth()
        )
        self.lDecodingErrorsValue.setSizePolicy(sizePolicy)
        self.lDecodingErrorsValue.setObjectName("lDecodingErrorsValue")
        self.gridLayout_3.addWidget(self.lDecodingErrorsValue, 2, 1, 1, 1)
        self.chkBoxOnlyShowLabelsInProtocol = QtWidgets.QCheckBox(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.chkBoxOnlyShowLabelsInProtocol.sizePolicy().hasHeightForWidth()
        )
        self.chkBoxOnlyShowLabelsInProtocol.setSizePolicy(sizePolicy)
        self.chkBoxOnlyShowLabelsInProtocol.setObjectName(
            "chkBoxOnlyShowLabelsInProtocol"
        )
        self.gridLayout_3.addWidget(self.chkBoxOnlyShowLabelsInProtocol, 5, 0, 1, 2)
        self.cbShowDiffs = QtWidgets.QCheckBox(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cbShowDiffs.sizePolicy().hasHeightForWidth())
        self.cbShowDiffs.setSizePolicy(sizePolicy)
        self.cbShowDiffs.setObjectName("cbShowDiffs")
        self.gridLayout_3.addWidget(self.cbShowDiffs, 3, 0, 1, 2)
        self.stackedWidgetLogicAnalysis = QtWidgets.QStackedWidget(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Maximum
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.stackedWidgetLogicAnalysis.sizePolicy().hasHeightForWidth()
        )
        self.stackedWidgetLogicAnalysis.setSizePolicy(sizePolicy)
        self.stackedWidgetLogicAnalysis.setObjectName("stackedWidgetLogicAnalysis")
        self.pageButtonAnalyzer = QtWidgets.QWidget()
        self.pageButtonAnalyzer.setObjectName("pageButtonAnalyzer")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.pageButtonAnalyzer)
        self.verticalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_8.setSpacing(0)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.btnAnalyze = QtWidgets.QToolButton(self.pageButtonAnalyzer)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnAnalyze.sizePolicy().hasHeightForWidth())
        self.btnAnalyze.setSizePolicy(sizePolicy)
        self.btnAnalyze.setPopupMode(QtWidgets.QToolButton.MenuButtonPopup)
        self.btnAnalyze.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.btnAnalyze.setObjectName("btnAnalyze")
        self.verticalLayout_8.addWidget(self.btnAnalyze)
        self.stackedWidgetLogicAnalysis.addWidget(self.pageButtonAnalyzer)
        self.pageProgressBar = QtWidgets.QWidget()
        self.pageProgressBar.setObjectName("pageProgressBar")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.pageProgressBar)
        self.verticalLayout_9.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_9.setSpacing(0)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.progressBarLogicAnalyzer = QtWidgets.QProgressBar(self.pageProgressBar)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.progressBarLogicAnalyzer.sizePolicy().hasHeightForWidth()
        )
        self.progressBarLogicAnalyzer.setSizePolicy(sizePolicy)
        self.progressBarLogicAnalyzer.setProperty("value", 24)
        self.progressBarLogicAnalyzer.setObjectName("progressBarLogicAnalyzer")
        self.verticalLayout_9.addWidget(self.progressBarLogicAnalyzer)
        self.stackedWidgetLogicAnalysis.addWidget(self.pageProgressBar)
        self.gridLayout_3.addWidget(self.stackedWidgetLogicAnalysis, 6, 0, 1, 2)
        self.verticalLayout_2.addLayout(self.gridLayout_3)
        self.layoutWidget1 = QtWidgets.QWidget(self.splitter)
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.layoutWidget1)
        self.verticalLayout.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout.setObjectName("verticalLayout")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.btnSaveProto = QtWidgets.QToolButton(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnSaveProto.sizePolicy().hasHeightForWidth())
        self.btnSaveProto.setSizePolicy(sizePolicy)
        self.btnSaveProto.setBaseSize(QtCore.QSize(0, 0))
        self.btnSaveProto.setText("")
        icon = QtGui.QIcon.fromTheme("document-save")
        self.btnSaveProto.setIcon(icon)
        self.btnSaveProto.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.btnSaveProto.setObjectName("btnSaveProto")
        self.gridLayout_2.addWidget(self.btnSaveProto, 0, 16, 1, 1)
        self.lSlash = QtWidgets.QLabel(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lSlash.sizePolicy().hasHeightForWidth())
        self.lSlash.setSizePolicy(sizePolicy)
        self.lSlash.setAlignment(QtCore.Qt.AlignCenter)
        self.lSlash.setObjectName("lSlash")
        self.gridLayout_2.addWidget(self.lSlash, 0, 7, 1, 1)
        self.lblShownRows = QtWidgets.QLabel(self.layoutWidget1)
        self.lblShownRows.setObjectName("lblShownRows")
        self.gridLayout_2.addWidget(self.lblShownRows, 0, 4, 1, 1)
        self.lTime = QtWidgets.QLabel(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lTime.sizePolicy().hasHeightForWidth())
        self.lTime.setSizePolicy(sizePolicy)
        self.lTime.setTextFormat(QtCore.Qt.PlainText)
        self.lTime.setAlignment(
            QtCore.Qt.AlignLeading | QtCore.Qt.AlignLeft | QtCore.Qt.AlignVCenter
        )
        self.lTime.setObjectName("lTime")
        self.gridLayout_2.addWidget(self.lTime, 0, 15, 1, 1)
        self.lSearchCurrent = QtWidgets.QLabel(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.lSearchCurrent.sizePolicy().hasHeightForWidth()
        )
        self.lSearchCurrent.setSizePolicy(sizePolicy)
        self.lSearchCurrent.setStyleSheet(
            "QLabel\n" "{\n" "    qproperty-alignment: AlignCenter;\n" "}"
        )
        self.lSearchCurrent.setObjectName("lSearchCurrent")
        self.gridLayout_2.addWidget(self.lSearchCurrent, 0, 6, 1, 1)
        self.lblRSSI = QtWidgets.QLabel(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblRSSI.sizePolicy().hasHeightForWidth())
        self.lblRSSI.setSizePolicy(sizePolicy)
        self.lblRSSI.setObjectName("lblRSSI")
        self.gridLayout_2.addWidget(self.lblRSSI, 0, 12, 1, 1)
        self.btnNextSearch = QtWidgets.QToolButton(self.layoutWidget1)
        self.btnNextSearch.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.btnNextSearch.sizePolicy().hasHeightForWidth()
        )
        self.btnNextSearch.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon.fromTheme("go-next")
        self.btnNextSearch.setIcon(icon)
        self.btnNextSearch.setObjectName("btnNextSearch")
        self.gridLayout_2.addWidget(self.btnNextSearch, 0, 9, 1, 1)
        self.btnPrevSearch = QtWidgets.QToolButton(self.layoutWidget1)
        self.btnPrevSearch.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.btnPrevSearch.sizePolicy().hasHeightForWidth()
        )
        self.btnPrevSearch.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon.fromTheme("go-previous")
        self.btnPrevSearch.setIcon(icon)
        self.btnPrevSearch.setObjectName("btnPrevSearch")
        self.gridLayout_2.addWidget(self.btnPrevSearch, 0, 5, 1, 1)
        self.lSearchTotal = QtWidgets.QLabel(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lSearchTotal.sizePolicy().hasHeightForWidth())
        self.lSearchTotal.setSizePolicy(sizePolicy)
        self.lSearchTotal.setStyleSheet(
            "QLabel\n" "{\n" "    qproperty-alignment: AlignCenter;\n" "}"
        )
        self.lSearchTotal.setObjectName("lSearchTotal")
        self.gridLayout_2.addWidget(self.lSearchTotal, 0, 8, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_3.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 0, 14, 1, 1)
        self.line_2 = QtWidgets.QFrame(self.layoutWidget1)
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridLayout_2.addWidget(self.line_2, 0, 13, 1, 1)
        self.btnSearchSelectFilter = QtWidgets.QToolButton(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.btnSearchSelectFilter.sizePolicy().hasHeightForWidth()
        )
        self.btnSearchSelectFilter.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon.fromTheme("edit-find")
        self.btnSearchSelectFilter.setIcon(icon)
        self.btnSearchSelectFilter.setPopupMode(QtWidgets.QToolButton.MenuButtonPopup)
        self.btnSearchSelectFilter.setToolButtonStyle(
            QtCore.Qt.ToolButtonTextBesideIcon
        )
        self.btnSearchSelectFilter.setAutoRaise(False)
        self.btnSearchSelectFilter.setArrowType(QtCore.Qt.NoArrow)
        self.btnSearchSelectFilter.setObjectName("btnSearchSelectFilter")
        self.gridLayout_2.addWidget(self.btnSearchSelectFilter, 0, 2, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(
            60, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum
        )
        self.gridLayout_2.addItem(spacerItem, 0, 10, 1, 1)
        self.line = QtWidgets.QFrame(self.layoutWidget1)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridLayout_2.addWidget(self.line, 0, 11, 1, 1)
        self.btnLoadProto = QtWidgets.QToolButton(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnLoadProto.sizePolicy().hasHeightForWidth())
        self.btnLoadProto.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon.fromTheme("document-open")
        self.btnLoadProto.setIcon(icon)
        self.btnLoadProto.setObjectName("btnLoadProto")
        self.gridLayout_2.addWidget(self.btnLoadProto, 0, 17, 1, 1)
        self.lblClearAlignment = QtWidgets.QLabel(self.layoutWidget1)
        self.lblClearAlignment.setObjectName("lblClearAlignment")
        self.gridLayout_2.addWidget(self.lblClearAlignment, 0, 3, 1, 1)
        self.lineEditSearch = QtWidgets.QLineEdit(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.lineEditSearch.sizePolicy().hasHeightForWidth()
        )
        self.lineEditSearch.setSizePolicy(sizePolicy)
        self.lineEditSearch.setAcceptDrops(False)
        self.lineEditSearch.setClearButtonEnabled(True)
        self.lineEditSearch.setObjectName("lineEditSearch")
        self.gridLayout_2.addWidget(self.lineEditSearch, 0, 1, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout_2)
        self.tblViewProtocol = ProtocolTableView(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.tblViewProtocol.sizePolicy().hasHeightForWidth()
        )
        self.tblViewProtocol.setSizePolicy(sizePolicy)
        self.tblViewProtocol.setAcceptDrops(True)
        self.tblViewProtocol.setAutoFillBackground(True)
        self.tblViewProtocol.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.tblViewProtocol.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.tblViewProtocol.setLineWidth(1)
        self.tblViewProtocol.setAutoScroll(True)
        self.tblViewProtocol.setDragDropMode(QtWidgets.QAbstractItemView.DropOnly)
        self.tblViewProtocol.setAlternatingRowColors(True)
        self.tblViewProtocol.setSelectionMode(
            QtWidgets.QAbstractItemView.ExtendedSelection
        )
        self.tblViewProtocol.setTextElideMode(QtCore.Qt.ElideNone)
        self.tblViewProtocol.setVerticalScrollMode(
            QtWidgets.QAbstractItemView.ScrollPerPixel
        )
        self.tblViewProtocol.setHorizontalScrollMode(
            QtWidgets.QAbstractItemView.ScrollPerPixel
        )
        self.tblViewProtocol.setShowGrid(False)
        self.tblViewProtocol.setGridStyle(QtCore.Qt.NoPen)
        self.tblViewProtocol.setSortingEnabled(False)
        self.tblViewProtocol.setWordWrap(False)
        self.tblViewProtocol.setCornerButtonEnabled(False)
        self.tblViewProtocol.setObjectName("tblViewProtocol")
        self.tblViewProtocol.horizontalHeader().setDefaultSectionSize(57)
        self.verticalLayout.addWidget(self.tblViewProtocol)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.lBits = QtWidgets.QLabel(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lBits.sizePolicy().hasHeightForWidth())
        self.lBits.setSizePolicy(sizePolicy)
        self.lBits.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.lBits.setObjectName("lBits")
        self.horizontalLayout_3.addWidget(self.lBits)
        self.lBitsSelection = QtWidgets.QLineEdit(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.lBitsSelection.sizePolicy().hasHeightForWidth()
        )
        self.lBitsSelection.setSizePolicy(sizePolicy)
        self.lBitsSelection.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.lBitsSelection.setAcceptDrops(False)
        self.lBitsSelection.setStyleSheet("background-color: rgba(255, 255, 255, 0);")
        self.lBitsSelection.setFrame(False)
        self.lBitsSelection.setReadOnly(True)
        self.lBitsSelection.setObjectName("lBitsSelection")
        self.horizontalLayout_3.addWidget(self.lBitsSelection)
        self.lHex = QtWidgets.QLabel(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lHex.sizePolicy().hasHeightForWidth())
        self.lHex.setSizePolicy(sizePolicy)
        self.lHex.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.lHex.setObjectName("lHex")
        self.horizontalLayout_3.addWidget(self.lHex)
        self.lHexSelection = QtWidgets.QLineEdit(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.lHexSelection.sizePolicy().hasHeightForWidth()
        )
        self.lHexSelection.setSizePolicy(sizePolicy)
        self.lHexSelection.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.lHexSelection.setAcceptDrops(False)
        self.lHexSelection.setStyleSheet("background-color: rgba(255, 255, 255, 0);")
        self.lHexSelection.setFrame(False)
        self.lHexSelection.setReadOnly(True)
        self.lHexSelection.setObjectName("lHexSelection")
        self.horizontalLayout_3.addWidget(self.lHexSelection)
        self.lDecimal = QtWidgets.QLabel(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lDecimal.sizePolicy().hasHeightForWidth())
        self.lDecimal.setSizePolicy(sizePolicy)
        self.lDecimal.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.lDecimal.setObjectName("lDecimal")
        self.horizontalLayout_3.addWidget(self.lDecimal)
        self.lDecimalSelection = QtWidgets.QLineEdit(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.lDecimalSelection.sizePolicy().hasHeightForWidth()
        )
        self.lDecimalSelection.setSizePolicy(sizePolicy)
        self.lDecimalSelection.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.lDecimalSelection.setAcceptDrops(False)
        self.lDecimalSelection.setStyleSheet(
            "background-color: rgba(255, 255, 255, 0);"
        )
        self.lDecimalSelection.setFrame(False)
        self.lDecimalSelection.setReadOnly(True)
        self.lDecimalSelection.setObjectName("lDecimalSelection")
        self.horizontalLayout_3.addWidget(self.lDecimalSelection)
        self.lNumSelectedColumns = QtWidgets.QLabel(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.lNumSelectedColumns.sizePolicy().hasHeightForWidth()
        )
        self.lNumSelectedColumns.setSizePolicy(sizePolicy)
        self.lNumSelectedColumns.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.lNumSelectedColumns.setObjectName("lNumSelectedColumns")
        self.horizontalLayout_3.addWidget(self.lNumSelectedColumns)
        self.lColumnsSelectedText = QtWidgets.QLabel(self.layoutWidget1)
        self.lColumnsSelectedText.setObjectName("lColumnsSelectedText")
        self.horizontalLayout_3.addWidget(self.lColumnsSelectedText)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.layoutWidget2 = QtWidgets.QWidget(self.splitter_2)
        self.layoutWidget2.setObjectName("layoutWidget2")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.layoutWidget2)
        self.verticalLayout_4.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(self.layoutWidget2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.lblLabelValues = QtWidgets.QLabel(self.layoutWidget2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.lblLabelValues.sizePolicy().hasHeightForWidth()
        )
        self.lblLabelValues.setSizePolicy(sizePolicy)
        self.lblLabelValues.setAlignment(QtCore.Qt.AlignCenter)
        self.lblLabelValues.setObjectName("lblLabelValues")
        self.gridLayout.addWidget(self.lblLabelValues, 0, 1, 1, 1)
        self.btnAddMessagetype = QtWidgets.QToolButton(self.layoutWidget2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.btnAddMessagetype.sizePolicy().hasHeightForWidth()
        )
        self.btnAddMessagetype.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon.fromTheme("list-add")
        self.btnAddMessagetype.setIcon(icon)
        self.btnAddMessagetype.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
        self.btnAddMessagetype.setObjectName("btnAddMessagetype")
        self.gridLayout.addWidget(self.btnAddMessagetype, 3, 0, 1, 1)
        self.tblLabelValues = LabelValueTableView(self.layoutWidget2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.tblLabelValues.sizePolicy().hasHeightForWidth()
        )
        self.tblLabelValues.setSizePolicy(sizePolicy)
        self.tblLabelValues.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.tblLabelValues.setAlternatingRowColors(True)
        self.tblLabelValues.setShowGrid(False)
        self.tblLabelValues.setObjectName("tblLabelValues")
        self.tblLabelValues.horizontalHeader().setVisible(True)
        self.tblLabelValues.horizontalHeader().setCascadingSectionResizes(False)
        self.tblLabelValues.horizontalHeader().setDefaultSectionSize(150)
        self.tblLabelValues.horizontalHeader().setStretchLastSection(True)
        self.tblLabelValues.verticalHeader().setVisible(False)
        self.gridLayout.addWidget(self.tblLabelValues, 1, 1, 3, 1)
        self.tblViewMessageTypes = MessageTypeTableView(self.layoutWidget2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.tblViewMessageTypes.sizePolicy().hasHeightForWidth()
        )
        self.tblViewMessageTypes.setSizePolicy(sizePolicy)
        self.tblViewMessageTypes.setAcceptDrops(False)
        self.tblViewMessageTypes.setToolTip("")
        self.tblViewMessageTypes.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.tblViewMessageTypes.setAlternatingRowColors(True)
        self.tblViewMessageTypes.setShowGrid(False)
        self.tblViewMessageTypes.setObjectName("tblViewMessageTypes")
        self.tblViewMessageTypes.verticalHeader().setVisible(False)
        self.gridLayout.addWidget(self.tblViewMessageTypes, 1, 0, 2, 1)
        self.verticalLayout_4.addLayout(self.gridLayout)
        self.verticalLayout_5.addWidget(self.splitter_2)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.verticalLayout_7.addWidget(self.scrollArea)

        self.retranslateUi(TabAnalysis)
        self.tabWidget.setCurrentIndex(0)
        self.stackedWidgetLogicAnalysis.setCurrentIndex(0)

    def retranslateUi(self, TabAnalysis):
        _translate = QtCore.QCoreApplication.translate
        TabAnalysis.setWindowTitle(_translate("TabAnalysis", "Frame"))
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.tab_protocols),
            _translate("TabAnalysis", "Protocols"),
        )
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.tab_participants),
            _translate("TabAnalysis", "Participants"),
        )
        self.label_5.setText(_translate("TabAnalysis", "Decoding:"))
        self.label_4.setText(_translate("TabAnalysis", "View data as:"))
        self.lEncodingErrors.setText(_translate("TabAnalysis", "Decoding errors:"))
        self.cbDecoding.setItemText(0, _translate("TabAnalysis", "NRZ"))
        self.cbDecoding.setItemText(1, _translate("TabAnalysis", "Manchester"))
        self.cbDecoding.setItemText(2, _translate("TabAnalysis", "Manchester II"))
        self.cbDecoding.setItemText(
            3, _translate("TabAnalysis", "Differential Manchester")
        )
        self.cbDecoding.setItemText(4, _translate("TabAnalysis", "..."))
        self.chkBoxShowOnlyDiffs.setText(
            _translate("TabAnalysis", "Show only diffs in protocol")
        )
        self.cbProtoView.setToolTip(
            _translate(
                "TabAnalysis",
                "<html><head/><body><p>Set the desired view here.</p></body></html>",
            )
        )
        self.cbProtoView.setItemText(0, _translate("TabAnalysis", "Bits"))
        self.cbProtoView.setItemText(1, _translate("TabAnalysis", "Hex"))
        self.cbProtoView.setItemText(2, _translate("TabAnalysis", "ASCII"))
        self.lDecodingErrorsValue.setText(_translate("TabAnalysis", "0 (0.00%)"))
        self.chkBoxOnlyShowLabelsInProtocol.setText(
            _translate("TabAnalysis", "Show only labels in protocol")
        )
        self.cbShowDiffs.setText(_translate("TabAnalysis", "Mark diffs in protocol"))
        self.btnAnalyze.setToolTip(
            _translate(
                "TabAnalysis",
                "<html><head/><body><p>Run some automatic analysis on the protocol e.g. assign labels automatically. You can configure which checks to run with the arrow on the right of this button.</p></body></html>",
            )
        )
        self.btnAnalyze.setText(_translate("TabAnalysis", "Analyze Protocol"))
        self.btnSaveProto.setToolTip(
            _translate("TabAnalysis", "Save current protocol.")
        )
        self.lSlash.setText(_translate("TabAnalysis", "/"))
        self.lblShownRows.setText(_translate("TabAnalysis", "shown: 42/108"))
        self.lTime.setToolTip(
            _translate(
                "TabAnalysis",
                '<html><head/><body><p>The <span style=" font-weight:600;">Message</span><span style=" font-weight:600;">Start</span> is the point in time when a protocol message begins. Additionally the relative time (+ ...) from the previous message is shown.</p></body></html>',
            )
        )
        self.lTime.setText(_translate("TabAnalysis", "0 (+0)"))
        self.lSearchCurrent.setText(_translate("TabAnalysis", "-"))
        self.lblRSSI.setToolTip(
            _translate(
                "TabAnalysis",
                "<html><head/><body><p>This is the average signal power of the current message. The nearer this value is to zero, the stronger the signal is.</p></body></html>",
            )
        )
        self.lblRSSI.setText(_translate("TabAnalysis", "-∞ dBm"))
        self.btnNextSearch.setText(_translate("TabAnalysis", ">"))
        self.btnPrevSearch.setText(_translate("TabAnalysis", "<"))
        self.lSearchTotal.setText(_translate("TabAnalysis", "-"))
        self.label_3.setToolTip(
            _translate(
                "TabAnalysis",
                '<html><head/><body><p>The <span style=" font-weight:600;">Message Start</span> is the point in time when a protocol message begins. Additionally the relative time (+ ...) from the previous message is shown.</p></body></html>',
            )
        )
        self.label_3.setText(_translate("TabAnalysis", "Timestamp:"))
        self.btnSearchSelectFilter.setText(_translate("TabAnalysis", "Search"))
        self.btnLoadProto.setToolTip(_translate("TabAnalysis", "Load a protocol."))
        self.btnLoadProto.setText(_translate("TabAnalysis", "..."))
        self.lblClearAlignment.setText(
            _translate(
                "TabAnalysis",
                '<html><head/><body><p><a href="reset_alignment"><span style=" text-decoration: underline; color:#0000ff;">Reset alignment</span></a></p></body></html>',
            )
        )
        self.lineEditSearch.setPlaceholderText(
            _translate("TabAnalysis", "Enter pattern here")
        )
        self.lBits.setText(_translate("TabAnalysis", "Bit:"))
        self.lHex.setText(_translate("TabAnalysis", "Hex:"))
        self.lDecimal.setText(_translate("TabAnalysis", "Decimal:"))
        self.lNumSelectedColumns.setText(_translate("TabAnalysis", "0"))
        self.lColumnsSelectedText.setText(
            _translate("TabAnalysis", "column(s) selected")
        )
        self.label.setText(_translate("TabAnalysis", "Message types"))
        self.lblLabelValues.setText(_translate("TabAnalysis", "Labels for message"))
        self.btnAddMessagetype.setToolTip(
            _translate("TabAnalysis", "Add a new message type")
        )
        self.btnAddMessagetype.setText(
            _translate("TabAnalysis", "Add new message type")
        )


from urh.ui.views.LabelValueTableView import LabelValueTableView
from urh.ui.views.MessageTypeTableView import MessageTypeTableView
from urh.ui.views.ProtocolTableView import ProtocolTableView
from urh.ui.views.ProtocolTreeView import ProtocolTreeView
from . import urh_rc



from subprocess import call, Popen

MODULES = ["path_creator", "signal_functions", "util", "auto_interpretation"]
COMPILER_DIRECTIVES = {
    "language_level": 3,
    "cdivision": True,
    "wraparound": False,
    "boundscheck": False,
    "initializedcheck": False,
}

for module in MODULES:
    call(
        [
            "cython",
            "-a",
            "-X",
            ",".join(
                "{}={}".format(key, val) for key, val in COMPILER_DIRECTIVES.items()
            ),
            "--cplus",
            "-3",
            module + ".pyx",
        ]
    )
    Popen(["firefox", module + ".html"])
